@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import sys
+import weakref
 from operator import attrgetter
 from typing import TYPE_CHECKING, Any, Callable, Iterator, Sequence, overload
 
@@ -9,11 +10,12 @@ import rich.repr
 if TYPE_CHECKING:
     from _typeshed import SupportsRichComparison
 
-    from .widget import Widget
+    from textual.dom import DOMNode
+    from textual.widget import Widget
 
 
 class DuplicateIds(Exception):
-    pass
+    """Raised when attempting to add a widget with an id that already exists."""
 
 
 @rich.repr.auto(angular=True)
@@ -24,7 +26,14 @@ class NodeList(Sequence["Widget"]):
     Although named a list, widgets may appear only once, making them more like a set.
     """
 
-    def __init__(self) -> None:
+    def __init__(self, parent: DOMNode | None = None) -> None:
+        """Initialize a node list.
+
+        Args:
+            parent: The parent node which holds a reference to this object, or `None` if
+                there is no parent.
+        """
+        self._parent = None if parent is None else weakref.ref(parent)
         # The nodes in the list
         self._nodes: list[Widget] = []
         self._nodes_set: set[Widget] = set()
@@ -52,6 +61,15 @@ class NodeList(Sequence["Widget"]):
     def __contains__(self, widget: object) -> bool:
         return widget in self._nodes
 
+    def updated(self) -> None:
+        """Mark the nodes as having been updated."""
+        self._updates += 1
+        node = None if self._parent is None else self._parent()
+        if node is None:
+            return
+        while node is not None and (node := node._parent) is not None:
+            node._nodes._updates += 1
+
     def _sort(
         self,
         *,
@@ -69,7 +87,7 @@ class NodeList(Sequence["Widget"]):
         else:
             self._nodes.sort(key=key, reverse=reverse)
 
-        self._updates += 1
+        self.updated()
 
     def index(self, widget: Any, start: int = 0, stop: int = sys.maxsize) -> int:
         """Return the index of the given widget.
@@ -102,7 +120,7 @@ class NodeList(Sequence["Widget"]):
             if widget_id is not None:
                 self._ensure_unique_id(widget_id)
                 self._nodes_by_id[widget_id] = widget
-            self._updates += 1
+            self.updated()
 
     def _insert(self, index: int, widget: Widget) -> None:
         """Insert a Widget.
@@ -117,9 +135,17 @@ class NodeList(Sequence["Widget"]):
             if widget_id is not None:
                 self._ensure_unique_id(widget_id)
                 self._nodes_by_id[widget_id] = widget
-            self._updates += 1
+            self.updated()
 
     def _ensure_unique_id(self, widget_id: str) -> None:
+        """Ensure a new widget ID would be unique.
+
+        Args:
+            widget_id: New widget ID.
+
+        Raises:
+            DuplicateIds: If the given ID is not unique.
+        """
         if widget_id in self._nodes_by_id:
             raise DuplicateIds(
                 f"Tried to insert a widget with ID {widget_id!r}, but a widget {self._nodes_by_id[widget_id]!r} "
@@ -141,7 +167,7 @@ class NodeList(Sequence["Widget"]):
             widget_id = widget.id
             if widget_id in self._nodes_by_id:
                 del self._nodes_by_id[widget_id]
-            self._updates += 1
+            self.updated()
 
     def _clear(self) -> None:
         """Clear the node list."""
@@ -149,7 +175,7 @@ class NodeList(Sequence["Widget"]):
             self._nodes.clear()
             self._nodes_set.clear()
             self._nodes_by_id.clear()
-            self._updates += 1
+            self.updated()
 
     def __iter__(self) -> Iterator[Widget]:
         return iter(self._nodes)
